@@ -79,7 +79,8 @@ var NAVTREE =
         [ "Table of Contents", "markdown.html#md_toc", null ],
         [ "Tables", "markdown.html#md_tables", null ],
         [ "Fenced Code Blocks", "markdown.html#md_fenced", null ],
-        [ "Header Id Attributes", "markdown.html#md_header_id", null ]
+        [ "Header Id Attributes", "markdown.html#md_header_id", null ],
+        [ "Image Attributes", "markdown.html#md_image_attributes", null ]
       ] ],
       [ "Doxygen specifics", "markdown.html#markdown_dox", [
         [ "Including Markdown files as pages", "markdown.html#md_page_header", null ],
@@ -91,7 +92,7 @@ var NAVTREE =
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
         [ "Limits on markup scope", "markdown.html#mddox_limits", null ]
       ] ],
-      [ "Debugging of problems", "markdown.html#markdown_debug", null ]
+      [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
     [ "Grouping", "grouping.html", [
@@ -149,7 +150,8 @@ var NAVTREE =
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
       [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
       [ "How did doxygen get its name?", "faq.html#faq_name", null ],
-      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ]
+      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ],
+      [ "How to prevent interleaved output", "faq.html#faq_bin", null ]
     ] ],
     [ "Troubleshooting", "trouble.html", [
       [ "Known Problems", "trouble.html#knowproblems", null ],
@@ -160,7 +162,21 @@ var NAVTREE =
     [ "Doxygen usage", "doxygen_usage.html", [
       [ "Fine-tuning the output", "doxygen_usage.html#doxygen_finetune", null ]
     ] ],
-    [ "Doxywizard usage", "doxywizard_usage.html", null ],
+    [ "Doxywizard usage", "doxywizard_usage.html", [
+      [ "Wizard tab", "doxywizard_usage.html#dw_wizard", [
+        [ "Project settings", "doxywizard_usage.html#dw_wizard_project", null ],
+        [ "Mode of operating", "doxywizard_usage.html#dw_wizard_mode", null ],
+        [ "Output to produce", "doxywizard_usage.html#dw_wizard_output", null ],
+        [ "Diagrams to generate", "doxywizard_usage.html#dw_wizard_diagrams", null ]
+      ] ],
+      [ "Expert tab", "doxywizard_usage.html#dw_expert", null ],
+      [ "Run tab", "doxywizard_usage.html#dw_run", null ],
+      [ "Menu options", "doxywizard_usage.html#dw_menu", [
+        [ "File menu", "doxywizard_usage.html#dw_menu_file", null ],
+        [ "Settings menu", "doxywizard_usage.html#dw_menu_settings", null ],
+        [ "Help menu", "doxywizard_usage.html#dw_menu_help", null ]
+      ] ]
+    ] ],
     [ "Configuration", "config.html", [
       [ "Format", "config.html#config_format", null ],
       [ "Project related configuration options", "config.html#config_project", null ],
@@ -176,6 +192,7 @@ var NAVTREE =
       [ "Configuration options related to the XML output", "config.html#config_xml", null ],
       [ "Configuration options related to the DOCBOOK output", "config.html#config_docbook", null ],
       [ "Configuration options for the AutoGen Definitions output", "config.html#config_autogen", null ],
+      [ "Configuration options related to Sqlite3 output", "config.html#config_sqlite3", null ],
       [ "Configuration options related to the Perl module output", "config.html#config_perlmod", null ],
       [ "Configuration options related to the preprocessor", "config.html#config_preprocessor", null ],
       [ "Configuration options related to external references", "config.html#config_external", null ],
@@ -195,6 +212,7 @@ var NAVTREE =
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
+      [ "\\concept <name>", "commands.html#cmdconcept", null ],
       [ "\\def <name>", "commands.html#cmddef", null ],
       [ "\\defgroup <name> (group title)", "commands.html#cmddefgroup", null ],
       [ "\\dir [<path fragment>]", "commands.html#cmddir", null ],
@@ -251,6 +269,7 @@ var NAVTREE =
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
+      [ "\\raisewarning ( text to be shown as warning )", "commands.html#cmdraisewarning", null ],
       [ "\\else", "commands.html#cmdelse", null ],
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
@@ -329,7 +348,7 @@ var NAVTREE =
       [ "\\dot [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddot", null ],
       [ "\\emoji \"name\"", "commands.html#cmdemoji", null ],
       [ "\\msc [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmsc", null ],
-      [ "\\startuml [{file}] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
+      [ "\\startuml ['{'option[,option]'}'] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
       [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
       [ "\\mscfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmscfile", null ],
       [ "\\diafile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddiafile", null ],
@@ -347,12 +366,14 @@ var NAVTREE =
       [ "\\endverbatim", "commands.html#cmdendverbatim", null ],
       [ "\\endxmlonly", "commands.html#cmdendxmlonly", null ],
       [ "\\f$", "commands.html#cmdfdollar", null ],
+      [ "\\f(", "commands.html#cmdfrndopen", null ],
+      [ "\\f)", "commands.html#cmdfrndclose", null ],
       [ "\\f[", "commands.html#cmdfbropen", null ],
       [ "\\f]", "commands.html#cmdfbrclose", null ],
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
       [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
-      [ "\\image['{'option'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
+      [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
       [ "\\li { item-description }", "commands.html#cmdli", null ],
@@ -391,12 +412,20 @@ var NAVTREE =
         [ "Creation of PDF and DVI output", "perlmod.html#pm_pdf_gen", null ]
       ] ],
       [ "Documentation format.", "perlmod.html#doxydocs_format", null ],
-      [ "Data structure", "perlmod.html#doxymodel_format", null ]
+      [ "Data structure", "perlmod.html#doxymodel_format", null ],
+      [ "Perl Module Tree Nodes", "perlmod.html#perlmod_tree", null ]
     ] ],
-    [ "Perl Module Tree Nodes", "perlmod_tree.html", null ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.3", "changelog.html#log_1_9_3", null ],
+        [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
+        [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
+        [ "Release 1.9.0", "changelog.html#log_1_9_0", null ]
+      ] ],
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.20", "changelog.html#log_1_8_20", null ],
+        [ "Release 1.8.19", "changelog.html#log_1_8_19", null ],
         [ "Release 1.8.18", "changelog.html#log_1_8_18", null ],
         [ "Release 1.8.17", "changelog.html#log_1_8_17", null ],
         [ "Release 1.8.16", "changelog.html#log_1_8_16", null ],
@@ -435,7 +464,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_preprocessor"
+"config.html#config_dot"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
